==> lasso_2.3.6.orig.tar.gz: lasso-2.3.6/lasso/xml/id-wsf-2.0/dstref_result_query.c <==
/* $Id: dstref_result_query.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $
 *
 * Lasso - A free implementation of the Liberty Alliance specifications.
 *
 * Copyright (C) 2004-2007 Entr'ouvert
 * http://lasso.entrouvert.org
 *
 * Authors: See AUTHORS file in top-level directory.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "../private.h"
#include "dstref_result_query.h"
#include "./idwsf2_strings.h"

/**
 * SECTION:dstref_result_query
 * @short_description: &lt;dstref:ResultQuery&gt;
 *
 * <figure><title>Schema fragment for dstref:ResultQuery</title>
 * <programlisting><![CDATA[
 *
 * <xs:complexType name="ResultQueryType">
 *   <xs:complexContent>
 *     <xs:extension base="dst:ResultQueryBaseType">
 *       <xs:sequence>
 *         <xs:element ref="dstref:Select" minOccurs="0" maxOccurs="1"/>
 *         <xs:element name="Sort" minOccurs="0" maxOccurs="1" type="dstref:SortType"/>
 *       </xs:sequence>
 *     </xs:extension>
 *   </xs:complexContent>
 * </xs:complexType>
 * ]]></programlisting>
 * </figure>
 */

/*****************************************************************************/
/* private methods                                                           */
/*****************************************************************************/


static struct XmlSnippet schema_snippets[] = {
	{ "Select", SNIPPET_CONTENT,
		G_STRUCT_OFFSET(LassoIdWsf2DstRefResultQuery, Select), NULL, NULL, NULL},
	{ "Sort", SNIPPET_CONTENT,
		G_STRUCT_OFFSET(LassoIdWsf2DstRefResultQuery, Sort), NULL, NULL, NULL},
	{ "", SNIPPET_COLLECT_NAMESPACES,
		G_STRUCT_OFFSET(LassoIdWsf2DstRefResultQuery, namespaces),
		NULL, NULL, NULL},
	{NULL, 0, 0, NULL, NULL, NULL}
};

static LassoNodeClass *parent_class = NULL;


/*****************************************************************************/
/* instance and class init functions                                         */
/*****************************************************************************/


static void
class_init(LassoIdWsf2DstRefResultQueryClass *klass)
{
	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);

	parent_class = g_type_class_peek_parent(klass);
	nclass->node_data = g_new0(LassoNodeClassData, 1);
	lasso_node_class_set_nodename(nclass, "ResultQuery");
	lasso_node_class_set_ns(nclass, LASSO_IDWSF2_DSTREF_HREF, LASSO_IDWSF2_DSTREF_PREFIX);
	lasso_node_class_add_snippets(nclass, schema_snippets);
}

GType
lasso_idwsf2_dstref_result_query_get_type()
{
	static GType this_type = 0;

	if (!this_type) {
		static const GTypeInfo this_info = {
			sizeof (LassoIdWsf2DstRefResultQueryClass),
			NULL,
			NULL,
			(GClassInitFunc) class_init,
			NULL,
			NULL,
			sizeof(LassoIdWsf2DstRefResultQuery),
			0,
			NULL,
			NULL
		};

		this_type = g_type_register_static(LASSO_TYPE_IDWSF2_DST_RESULT_QUERY_BASE,
				"LassoIdWsf2DstRefResultQuery", &this_info, 0);
	}
	return this_type;
}

/**
 * lasso_idwsf2_dstref_result_query_new:
 *
 * Creates a new #LassoIdWsf2DstRefResultQuery object.
 *
 * Return value: a newly created #LassoIdWsf2DstRefResultQuery object
 **/
LassoIdWsf2DstRefResultQuery*
lasso_idwsf2_dstref_result_query_new()
{
	return g_object_new(LASSO_TYPE_IDWSF2_DSTREF_RESULT_QUERY, NULL);
}

==> lasso_2.4.0.orig.tar.gz: lasso-2.4.0/lasso/xml/id-wsf-2.0/dstref_result_query.c <==
/* $Id: dstref_result_query.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $
 *
 * Lasso - A free implementation of the Liberty Alliance specifications.
 *
 * Copyright (C) 2004-2007 Entr'ouvert
 * http://lasso.entrouvert.org
 *
 * Authors: See AUTHORS file in top-level directory.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */

#include "../private.h"
#include "dstref_result_query.h"
#include "idwsf2_strings.h"

/**
 * SECTION:dstref_result_query
 * @short_description: &lt;dstref:ResultQuery&gt;
 *
 * <figure><title>Schema fragment for dstref:ResultQuery</title>
 * <programlisting><![CDATA[
 *
 * <xs:complexType name="ResultQueryType">
 *   <xs:complexContent>
 *     <xs:extension base="dst:ResultQueryBaseType">
 *       <xs:sequence>
 *         <xs:element ref="dstref:Select" minOccurs="0" maxOccurs="1"/>
 *         <xs:element name="Sort" minOccurs="0" maxOccurs="1" type="dstref:SortType"/>
 *       </xs:sequence>
 *     </xs:extension>
 *   </xs:complexContent>
 * </xs:complexType>
 * ]]></programlisting>
 * </figure>
 */

/*****************************************************************************/
/* private methods                                                           */
/*****************************************************************************/


static struct XmlSnippet schema_snippets[] = {
	{ "Select", SNIPPET_CONTENT,
		G_STRUCT_OFFSET(LassoIdWsf2DstRefResultQuery, Select), NULL, NULL, NULL},
	{ "Sort", SNIPPET_CONTENT,
		G_STRUCT_OFFSET(LassoIdWsf2DstRefResultQuery, Sort), NULL, NULL, NULL},
	{ "", SNIPPET_COLLECT_NAMESPACES,
		G_STRUCT_OFFSET(LassoIdWsf2DstRefResultQuery, namespaces),
		NULL, NULL, NULL},
	{NULL, 0, 0, NULL, NULL, NULL}
};

static LassoNodeClass *parent_class = NULL;


/*****************************************************************************/
/* instance and class init functions                                         */
/*****************************************************************************/


static void
class_init(LassoIdWsf2DstRefResultQueryClass *klass)
{
	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);

	parent_class = g_type_class_peek_parent(klass);
	nclass->node_data = g_new0(LassoNodeClassData, 1);
	lasso_node_class_set_nodename(nclass, "ResultQuery");
	lasso_node_class_set_ns(nclass, LASSO_IDWSF2_DSTREF_HREF, LASSO_IDWSF2_DSTREF_PREFIX);
	lasso_node_class_add_snippets(nclass, schema_snippets);
}

GType
lasso_idwsf2_dstref_result_query_get_type()
{
	static GType this_type = 0;

	if (!this_type) {
		static const GTypeInfo this_info = {
			sizeof (LassoIdWsf2DstRefResultQueryClass),
			NULL,
			NULL,
			(GClassInitFunc) class_init,
			NULL,
			NULL,
			sizeof(LassoIdWsf2DstRefResultQuery),
			0,
			NULL,
			NULL
		};

		this_type = g_type_register_static(LASSO_TYPE_IDWSF2_DST_RESULT_QUERY_BASE,
				"LassoIdWsf2DstRefResultQuery", &this_info, 0);
	}
	return this_type;
}

/**
 * lasso_idwsf2_dstref_result_query_new:
 *
 * Creates a new #LassoIdWsf2DstRefResultQuery object.
 *
 * Return value: a newly created #LassoIdWsf2DstRefResultQuery object
 **/
LassoIdWsf2DstRefResultQuery*
lasso_idwsf2_dstref_result_query_new()
{
	return g_object_new(LASSO_TYPE_IDWSF2_DSTREF_RESULT_QUERY, NULL);
}
